==> CGAL-5.2.2-doc_html.tar.xz: doc_html/Shape_detection/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.2.2 - Shape Detection", "index.html", [
    [ "User Manual", "index.html", [
      [ "Introduction", "index.html#Shape_detection_Introduction", null ],
      [ "Efficient RANSAC", "index.html#Shape_detection_RANSAC", [
        [ "Parameters", "index.html#Shape_detection_RANSACParameters", null ],
        [ "Examples", "index.html#Shape_detection_RANSACExamples", [
          [ "Basic Plane Detection", "index.html#Shape_detection_RANSACExample_basic", null ],
          [ "Plane Detection With Callback", "index.html#Shape_detection_RANSACExample_with_callback", null ],
          [ "Setting Parameters And Using Different Shape Types", "index.html#Shape_detection_RANSACExample_with_parameters", null ],
          [ "Retrieving Points Assigned To Shapes", "index.html#Shape_detection_RANSACExample_with_point_access", null ],
          [ "Custom Shapes", "index.html#Shape_detection_RANSACExample_with_custom_shapes", null ]
        ] ],
        [ "Performance", "index.html#Shape_detection_RANSACPerformance", null ]
      ] ],
      [ "Region Growing", "index.html#Shape_detection_RegionGrowing", [
        [ "Framework", "index.html#Shape_detection_RegionGrowingFramework", [
          [ "Neighborhood", "index.html#Shape_detection_RegionGrowingFramework_connectivity", null ],
          [ "Regions", "index.html#Shape_detection_RegionGrowingFramework_conditions", null ],
          [ "Seeding", "index.html#Shape_detection_RegionGrowingFramework_seeding", null ],
          [ "Examples", "index.html#Shape_detection_RegionGrowingFramework_examples", null ]
        ] ],
        [ "Point Set", "index.html#Shape_detection_RegionGrowingPoints", [
          [ "Parameters", "index.html#Shape_detection_RegionGrowingPoints_parameters", null ],
          [ "Examples", "index.html#Shape_detection_RegionGrowingPoints_examples", null ],
          [ "Performance", "index.html#Shape_detection_RegionGrowingPoints_performance", null ]
        ] ],
        [ "Polygon Mesh", "index.html#Shape_detection_RegionGrowingMesh", [
          [ "Parameters", "index.html#Shape_detection_RegionGrowingMesh_parameters", null ],
          [ "Examples", "index.html#Shape_detection_RegionGrowingMesh_examples", null ],
          [ "Performance", "index.html#Shape_detection_RegionGrowingMesh_performance", null ]
        ] ]
      ] ],
      [ "Comparison", "index.html#Shape_detection_Comparison", null ],
      [ "Plane Regularization", "index.html#Shape_detection_PlaneRegularization", null ],
      [ "Deprecated Components", "index.html#Shape_detection_DeprecatedComponents", null ],
      [ "History", "index.html#Shape_detection_History", null ],
      [ "Acknowledgments", "index.html#Shape_detection_Acknowledgments", null ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Is Model Relationships", "models.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
".html",
"group__PkgShapeDetectionRGOnMesh.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> CGAL-5.4.1-doc_html.tar.xz: doc_html/Shape_detection/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.4.1 - Shape Detection", "index.html", [
    [ "User Manual", "index.html", [
      [ "Introduction", "index.html#Shape_detection_Introduction", null ],
      [ "Efficient RANSAC", "index.html#Shape_detection_RANSAC", [
        [ "Parameters", "index.html#Shape_detection_RANSACParameters", null ],
        [ "Examples", "index.html#Shape_detection_RANSACExamples", [
          [ "Basic Plane Detection", "index.html#Shape_detection_RANSACExample_basic", null ],
          [ "Plane Detection With Callback", "index.html#Shape_detection_RANSACExample_with_callback", null ],
          [ "Setting Parameters And Using Different Shape Types", "index.html#Shape_detection_RANSACExample_with_parameters", null ],
          [ "Retrieving Points Assigned To Shapes", "index.html#Shape_detection_RANSACExample_with_point_access", null ],
          [ "Custom Shapes", "index.html#Shape_detection_RANSACExample_with_custom_shapes", null ]
        ] ],
        [ "Performance", "index.html#Shape_detection_RANSACPerformance", null ]
      ] ],
      [ "Region Growing", "index.html#Shape_detection_RegionGrowing", [
        [ "Framework", "index.html#Shape_detection_RegionGrowingFramework", [
          [ "Neighborhood", "index.html#Shape_detection_RegionGrowingFramework_connectivity", null ],
          [ "Regions", "index.html#Shape_detection_RegionGrowingFramework_conditions", null ],
          [ "Seeding", "index.html#Shape_detection_RegionGrowingFramework_seeding", null ],
          [ "Examples", "index.html#Shape_detection_RegionGrowingFramework_examples", null ]
        ] ],
        [ "Point Set", "index.html#Shape_detection_RegionGrowingPoints", [
          [ "Parameters", "index.html#Shape_detection_RegionGrowingPoints_parameters", null ],
          [ "Examples", "index.html#Shape_detection_RegionGrowingPoints_examples", [
            [ "Detecting 2D Lines", "index.html#Shape_detection_RegionGrowingPoints_example_2D_lines", null ],
            [ "Detecting 2D Circles", "index.html#Shape_detection_RegionGrowingPoints_example_2D_circles", null ],
            [ "Detecting 3D Planes", "index.html#Shape_detection_RegionGrowingPoints_example_3D_planes", null ],
            [ "Detecting 3D Spheres", "index.html#Shape_detection_RegionGrowingPoints_example_3D_spheres", null ],
            [ "Detecting 3D Cylinders", "index.html#Shape_detection_RegionGrowingPoints_example_3D_cylinders", null ]
          ] ],
          [ "Performance", "index.html#Shape_detection_RegionGrowingPoints_performance", null ]
        ] ],
        [ "Polygon Mesh", "index.html#Shape_detection_RegionGrowingMesh", [
          [ "Parameters", "index.html#Shape_detection_RegionGrowingMesh_parameters", null ],
          [ "Examples", "index.html#Shape_detection_RegionGrowingMesh_examples", null ],
          [ "Performance", "index.html#Shape_detection_RegionGrowingMesh_performance", null ]
        ] ]
      ] ],
      [ "Comparison", "index.html#Shape_detection_Comparison", null ],
      [ "Deprecated Components", "index.html#Shape_detection_DeprecatedComponents", null ],
      [ "History", "index.html#Shape_detection_History", null ],
      [ "Acknowledgments", "index.html#Shape_detection_Acknowledgments", null ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Is Model Relationships", "models.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
".html",
"classEfficientRANSACTraits.html#ac0e5d78c7b6966a2210e277a5dd3d106"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
